@@ -24,12 +24,9 @@
 #include "panel-applet-frame.h"
 #include "panel-action-button.h"
 #include "panel-menu-bar.h"
-#include "panel-separator.h"
 #include "panel-toplevel.h"
 #include "panel-util.h"
 #include "panel-menu-button.h"
-#include "panel-globals.h"
-#include "panel-properties-dialog.h"
 #include "panel-layout.h"
 #include "panel-lockdown.h"
 #include "panel-schemas.h"
@@ -67,7 +64,6 @@ panel_applet_set_dnd_enabled (AppletInfo *info,
 						     dnd_enabled);
 		break;
 	case PANEL_OBJECT_MENU_BAR:
-	case PANEL_OBJECT_SEPARATOR:
 	case PANEL_OBJECT_USER_MENU:
 		break;
 	default:
@@ -193,7 +189,6 @@ applet_callback_callback (GtkWidget      *widget,
 		 * Applet's menu's are handled differently
 		 */
 		break;
-	case PANEL_OBJECT_SEPARATOR:
 	case PANEL_OBJECT_USER_MENU:
 		break;
 	default:
@@ -507,30 +502,6 @@ panel_applet_get_edit_menu (AppletInfo *info)
 	return info->edit_menu;
 }
 
-
-void
-panel_applet_menu_set_recurse (GtkMenu     *menu,
-			       const gchar *key,
-			       gpointer     data)
-{
-	GList *children;
-	GList *l;
-
-	g_object_set_data (G_OBJECT (menu), key, data);
-
-	children = gtk_container_get_children (GTK_CONTAINER (menu));
-
-	for (l = children; l; l = l->next) {
-		GtkWidget *submenu = gtk_menu_item_get_submenu (GTK_MENU_ITEM (l->data));
-
-		if (submenu)
-			panel_applet_menu_set_recurse (
-				GTK_MENU (submenu), key, data);
-	}
-
-	g_list_free (children);
-}
-
 void
 panel_applet_position_menu (GtkMenu   *menu,
 			    int       *x,
@@ -627,10 +598,6 @@ applet_show_menu (AppletInfo     *info,
 
 	panel_widget = panel_applet_get_panel_widget (info);
 
-	panel_applet_menu_set_recurse (GTK_MENU (menu),
-				       "menu_panel",
-				       panel_widget);
-
 	gtk_menu_set_screen (GTK_MENU (menu),
 			     gtk_window_get_screen (GTK_WINDOW (panel_widget->toplevel)));
 
@@ -985,7 +952,6 @@ panel_applet_register (GtkWidget       *applet,
 	gtk_widget_show (applet);
 
 	orientation_change (info, panel);
-	back_change (info, panel);
 
 	if (type != PANEL_OBJECT_APPLET)
 		gtk_widget_grab_focus (applet);
