@@ -80,10 +80,6 @@ GSettings  *panel_applet_get_settings    (AppletInfo *applet);
    (position, toplevel_id, panel_right_stick) */
 gboolean    panel_applet_can_freely_move (AppletInfo *applet);
 
-void        panel_applet_menu_set_recurse (GtkMenu     *menu,
-					   const gchar *key,
-					   gpointer     data);
-
 void panel_applet_position_menu (GtkMenu   *menu,
 				 int       *x,
 				 int       *y,
