@@ -11,9 +11,7 @@
 #include "panel-widget.h"
 #include "panel-types.h"
 #include "panel-util.h"
-#include "panel-marshal.h"
 #include "panel-typebuiltins.h"
-#include "panel-globals.h"
 
 #define BUTTON_WIDGET_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BUTTON_TYPE_WIDGET, ButtonWidgetPrivate))
 
@@ -29,7 +27,6 @@ struct _ButtonWidgetPrivate {
 	int               size;
 
 	guint             activatable   : 1;
-	guint             ignore_leave  : 1;
 	guint             arrow         : 1;
 	guint             dnd_highlight : 1;
 };
@@ -40,7 +37,6 @@ static void button_widget_reload_pixbuf (ButtonWidget *button);
 enum {
 	PROP_0,
 	PROP_ACTIVATABLE,
-	PROP_IGNORE_LEAVE,
 	PROP_HAS_ARROW,
 	PROP_DND_HIGHLIGHT,
 	PROP_ORIENTATION,
@@ -171,11 +167,11 @@ button_widget_reload_pixbuf (ButtonWidget *button)
 					 button->priv->orientation & PANEL_HORIZONTAL_MASK ? button->priv->size : -1,
 					 &error);
 		if (error) {
-			//FIXME: this is not rendered at button->priv->size
-			button->priv->pixbuf =
-				gtk_widget_render_icon_pixbuf (GTK_WIDGET (button),
-                                                               GTK_STOCK_MISSING_IMAGE,
-                                                               (GtkIconSize) -1);
+			button->priv->pixbuf = gtk_icon_theme_load_icon (button->priv->icon_theme,
+			                                                 "image-missing",
+			                                                 button->priv->size,
+			                                                 0, NULL);
+
 			g_free (error);
 		}
 
@@ -221,9 +217,6 @@ button_widget_get_property (GObject    *object,
 	case PROP_ACTIVATABLE:
 		g_value_set_boolean (value, button->priv->activatable);
 		break;
-	case PROP_IGNORE_LEAVE:
-		g_value_set_boolean (value, button->priv->ignore_leave);
-		break;
 	case PROP_HAS_ARROW:
 		g_value_set_boolean (value, button->priv->arrow);
 		break;
@@ -256,9 +249,6 @@ button_widget_set_property (GObject      *object,
 	case PROP_ACTIVATABLE:
 		button_widget_set_activatable (button, g_value_get_boolean (value));
 		break;
-	case PROP_IGNORE_LEAVE:
-		button_widget_set_ignore_leave (button, g_value_get_boolean (value));
-		break;
 	case PROP_HAS_ARROW:
 		button_widget_set_has_arrow (button, g_value_get_boolean (value));
 		break;
@@ -319,6 +309,8 @@ calc_arrow (PanelOrientation  orientation,
                 *angle = 3 * (G_PI / 2);
 		retval = GTK_ARROW_LEFT;
 		break;
+	default:
+		break;
 	}
 
 	return retval;
@@ -408,21 +400,11 @@ button_widget_draw (GtkWidget *widget,
 	}
 
 	if (gtk_widget_has_focus (widget)) {
-		gint focus_pad;
-
                 gtk_style_context_save (context);
                 gtk_style_context_set_state (context, state_flags);
 
-		gtk_widget_style_get (widget,
-				      "focus-padding", &focus_pad,
-				      NULL);
-		x = focus_pad;
-		y = focus_pad;
-		w = width -  2 * focus_pad;
-		h = height - 2 * focus_pad;
-
                 cairo_save (cr);
-		gtk_render_focus (context, cr, x, y, w, h);
+		gtk_render_focus (context, cr, 0, 0, width, height);
                 cairo_restore (cr);
 
                 gtk_style_context_restore (context);
@@ -555,7 +537,7 @@ static gboolean
 button_widget_enter_notify (GtkWidget *widget, GdkEventCrossing *event)
 {
 	GtkStateFlags state_flags;
-	gboolean in_button;
+	guint in_button;
 	gboolean hover_highlight;
 
 	g_return_val_if_fail (BUTTON_IS_WIDGET (widget), FALSE);
@@ -579,7 +561,7 @@ static gboolean
 button_widget_leave_notify (GtkWidget *widget, GdkEventCrossing *event)
 {
 	GtkStateFlags state_flags;
-	gboolean in_button;
+	guint in_button;
 	gboolean hover_highlight;
 
 	g_return_val_if_fail (BUTTON_IS_WIDGET (widget), FALSE);
@@ -619,7 +601,6 @@ button_widget_init (ButtonWidget *button)
 	button->priv->size = 0;
 	
 	button->priv->activatable   = FALSE;
-	button->priv->ignore_leave  = FALSE;
 	button->priv->arrow         = FALSE;
 	button->priv->dnd_highlight = FALSE;
 }
@@ -658,15 +639,6 @@ button_widget_class_init (ButtonWidgetClass *klass)
 					      TRUE,
 					      G_PARAM_READWRITE | G_PARAM_CONSTRUCT));
 
-	g_object_class_install_property (
-			gobject_class,
-			PROP_IGNORE_LEAVE,
-			g_param_spec_boolean ("ignore-leave",
-					      "Ignore leaving to not unhighlight the icon",
-					      "Whether or not to unhighlight the icon when the cursor leaves it",
-					      FALSE,
-					      G_PARAM_READWRITE));
-
 	g_object_class_install_property (
 			gobject_class,
 			PROP_HAS_ARROW,
@@ -748,14 +720,6 @@ button_widget_set_activatable (ButtonWidget *button,
 	}
 }
 
-gboolean
-button_widget_get_activatable (ButtonWidget *button)
-{
-	g_return_val_if_fail (BUTTON_IS_WIDGET (button), FALSE);
-
-	return button->priv->activatable;
-}
-
 void
 button_widget_set_icon_name (ButtonWidget *button,
 			     const char   *icon_name)
@@ -775,14 +739,6 @@ button_widget_set_icon_name (ButtonWidget *button,
 	g_object_notify (G_OBJECT (button), "icon-name");
 }
 
-const char *
-button_widget_get_icon_name (ButtonWidget *button)
-{
-	g_return_val_if_fail (BUTTON_IS_WIDGET (button), NULL);
-
-	return button->priv->filename;
-}
-
 void
 button_widget_set_orientation (ButtonWidget     *button,
 			       PanelOrientation  orientation)
@@ -840,14 +796,6 @@ button_widget_set_has_arrow (ButtonWidget *button,
 	g_object_notify (G_OBJECT (button), "has-arrow");
 }
 
-gboolean
-button_widget_get_has_arrow (ButtonWidget *button)
-{
-	g_return_val_if_fail (BUTTON_IS_WIDGET (button), FALSE);
-
-	return button->priv->arrow;
-}
-
 void
 button_widget_set_dnd_highlight (ButtonWidget *button,
 				 gboolean      dnd_highlight)
@@ -866,40 +814,6 @@ button_widget_set_dnd_highlight (ButtonWidget *button,
 	g_object_notify (G_OBJECT (button), "dnd-highlight");
 }
 
-gboolean
-button_widget_get_dnd_highlight (ButtonWidget *button)
-{
-	g_return_val_if_fail (BUTTON_IS_WIDGET (button), FALSE);
-
-	return button->priv->dnd_highlight;
-}
-
-void
-button_widget_set_ignore_leave (ButtonWidget *button,
-				gboolean      ignore_leave)
-{
-	g_return_if_fail (BUTTON_IS_WIDGET (button));
-
-	ignore_leave = ignore_leave != FALSE;
-
-	if (button->priv->ignore_leave == ignore_leave)
-		return;
-
-	button->priv->ignore_leave = ignore_leave;
-
-	gtk_widget_queue_draw (GTK_WIDGET (button));
-
-	g_object_notify (G_OBJECT (button), "ignore-leave");
-}
-
-gboolean
-button_widget_get_ignore_leave (ButtonWidget *button)
-{
-	g_return_val_if_fail (BUTTON_IS_WIDGET (button), FALSE);
-
-	return button->priv->ignore_leave;
-}
-
 GtkIconTheme *
 button_widget_get_icon_theme (ButtonWidget *button)
 {
