@@ -15,14 +15,14 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, see <http://www.gnu.org/licenses/>.
- *
  */
 
+#include "config.h"
+
 #include <string.h>
-#include <gtk/gtkx.h>
 #include <panel-applets-manager.h>
+
 #include "panel-applet-container.h"
-#include "panel-marshal.h"
 
 struct _PanelAppletContainerPrivate {
 	GDBusProxy *applet_proxy;
@@ -31,16 +31,12 @@ struct _PanelAppletContainerPrivate {
 	gchar      *bus_name;
 
 	gchar      *iid;
-	gboolean    out_of_process;
-	guint32     xid;
 	guint32     uid;
-	GtkWidget  *socket;
 
 	GHashTable *pending_ops;
 };
 
 enum {
-	APPLET_BROKEN,
 	APPLET_MOVE,
 	APPLET_REMOVE,
 	CHILD_PROPERTY_CHANGED,
@@ -58,7 +54,6 @@ static const AppletPropertyInfo applet_properties [] = {
 	{ "settings-path", "SettingsPath" },
 	{ "orient",        "Orient" },
 	{ "size-hints",    "SizeHints" },
-	{ "background",    "Background" },
 	{ "flags",         "Flags" },
 	{ "locked-down",   "LockedDown" }
 };
@@ -71,8 +66,6 @@ static const AppletPropertyInfo applet_properties [] = {
 #define PANEL_APPLET_FACTORY_OBJECT_PATH "/org/gnome/panel/applet/%s"
 #define PANEL_APPLET_INTERFACE           "org.gnome.panel.applet.Applet"
 
-static gboolean panel_applet_container_plug_removed (PanelAppletContainer *container);
-
 G_DEFINE_TYPE (PanelAppletContainer, panel_applet_container, GTK_TYPE_EVENT_BOX);
 
 GQuark
@@ -95,23 +88,10 @@ panel_applet_container_init (PanelAppletContainer *container)
 static void
 panel_applet_container_setup (PanelAppletContainer *container)
 {
-	if (container->priv->out_of_process) {
-		container->priv->socket = gtk_socket_new ();
+	GtkWidget *applet;
 
-		g_signal_connect_swapped (container->priv->socket,
-		                          "plug-removed",
-		                          G_CALLBACK (panel_applet_container_plug_removed),
-		                          container);
-
-		gtk_container_add (GTK_CONTAINER (container), container->priv->socket);
-		gtk_widget_show (container->priv->socket);
-	} else {
-		GtkWidget *applet;
-
-		applet = panel_applets_manager_get_applet_widget (container->priv->iid, container->priv->uid);
-
-		gtk_container_add (GTK_CONTAINER (container), applet);
-	}
+	applet = panel_applets_manager_get_applet_widget (container->priv->iid, container->priv->uid);
+	gtk_container_add (GTK_CONTAINER (container), applet);
 }
 
 static void
@@ -176,16 +156,6 @@ panel_applet_container_class_init (PanelAppletContainerClass *klass)
 
 	gobject_class->dispose = panel_applet_container_dispose;
 
-	signals[APPLET_BROKEN] =
-		g_signal_new ("applet-broken",
-			      G_TYPE_FROM_CLASS (klass),
-			      G_SIGNAL_RUN_LAST,
-			      G_STRUCT_OFFSET (PanelAppletContainerClass, applet_broken),
-			      NULL,
-			      NULL,
-			      g_cclosure_marshal_VOID__VOID,
-			      G_TYPE_NONE,
-			      0);
 	signals[APPLET_MOVE] =
 		g_signal_new ("applet-move",
 			      G_TYPE_FROM_CLASS (klass),
@@ -193,7 +163,7 @@ panel_applet_container_class_init (PanelAppletContainerClass *klass)
 			      G_STRUCT_OFFSET (PanelAppletContainerClass, applet_move),
 			      NULL,
 			      NULL,
-			      g_cclosure_marshal_VOID__VOID,
+			      NULL,
 			      G_TYPE_NONE,
 			      0);
 	signals[APPLET_REMOVE] =
@@ -203,7 +173,7 @@ panel_applet_container_class_init (PanelAppletContainerClass *klass)
 			      G_STRUCT_OFFSET (PanelAppletContainerClass, applet_remove),
 			      NULL,
 			      NULL,
-			      g_cclosure_marshal_VOID__VOID,
+			      NULL,
 			      G_TYPE_NONE,
 			      0);
 	signals[CHILD_PROPERTY_CHANGED] =
@@ -214,7 +184,7 @@ panel_applet_container_class_init (PanelAppletContainerClass *klass)
 			      G_STRUCT_OFFSET (PanelAppletContainerClass, child_property_changed),
 			      NULL,
 			      NULL,
-			      panel_marshal_VOID__STRING_POINTER,
+			      NULL,
 			      G_TYPE_NONE, 2,
 			      G_TYPE_STRING,
 			      G_TYPE_POINTER);
@@ -245,35 +215,6 @@ panel_applet_container_new (void)
 	return container;
 }
 
-static gboolean
-panel_applet_container_plug_removed (PanelAppletContainer *container)
-{
-	if (!container->priv->applet_proxy)
-		return FALSE;
-
-	panel_applet_container_cancel_pending_operations (container);
-
-	if (container->priv->name_watcher_id > 0) {
-		g_bus_unwatch_name (container->priv->name_watcher_id);
-		container->priv->name_watcher_id = 0;
-	}
-
-	g_object_unref (container->priv->applet_proxy);
-	container->priv->applet_proxy = NULL;
-
-	/* The "plug-removed" signal is also emitted when the socket is being
-	 * unrealized (eg., when PanelAppletContainer is torn down during
-	 * cleanup on exit). Only emit "applet-broken" if the socket is
-	 * still realized. */
-	if (gtk_widget_get_realized (container->priv->socket))
-		g_signal_emit (container, signals[APPLET_BROKEN], 0);
-
-	/* Continue destroying, in case of reloading
-	 * a new frame widget is created
-	 */
-	return FALSE;
-}
-
 static void
 panel_applet_container_child_signal (GDBusProxy           *proxy,
 				     gchar                *sender_name,
@@ -359,12 +300,6 @@ on_proxy_appeared (GObject      *source_object,
 	g_object_unref (task);
 
 	panel_applet_container_setup (container);
-
-	if (container->priv->xid > 0) {
-		gtk_socket_add_id (GTK_SOCKET (container->priv->socket),
-				   container->priv->xid);
-	}
-
 	g_object_unref (container);
 }
 
@@ -391,12 +326,7 @@ get_applet_cb (GObject      *source_object,
 
 	container = PANEL_APPLET_CONTAINER (g_async_result_get_source_object (G_ASYNC_RESULT (task)));
 
-	g_variant_get (retvals,
-	               "(&obuu)",
-	               &applet_path,
-	               &container->priv->out_of_process,
-	               &container->priv->xid,
-	               &container->priv->uid);
+	g_variant_get (retvals, "(&ou)", &applet_path, &container->priv->uid);
 
 	g_dbus_proxy_new (connection,
 			  G_DBUS_PROXY_FLAGS_DO_NOT_LOAD_PROPERTIES,
@@ -450,7 +380,7 @@ on_factory_appeared (GDBusConnection   *connection,
 				PANEL_APPLET_FACTORY_INTERFACE,
 				"GetApplet",
 				data->parameters,
-				G_VARIANT_TYPE ("(obuu)"),
+				G_VARIANT_TYPE ("(ou)"),
 				G_DBUS_CALL_FLAGS_NONE,
 				-1,
 				data->cancellable,
@@ -461,7 +391,6 @@ on_factory_appeared (GDBusConnection   *connection,
 
 static void
 panel_applet_container_get_applet (PanelAppletContainer *container,
-				   GdkScreen            *screen,
 				   const gchar          *iid,
 				   GVariant             *props,
 				   GCancellable         *cancellable,
@@ -470,7 +399,6 @@ panel_applet_container_get_applet (PanelAppletContainer *container,
 {
 	GTask              *task;
 	AppletFactoryData  *data;
-	gint                screen_number;
 	gchar              *bus_name;
 	gchar              *factory_id;
 	gchar              *applet_id;
@@ -492,14 +420,10 @@ panel_applet_container_get_applet (PanelAppletContainer *container,
 	factory_id = g_strndup (iid, strlen (iid) - strlen (applet_id));
 	applet_id += 2;
 
-	/* we can't use the screen of the container widget since it's not in a
-	 * widget hierarchy yet */
-	screen_number = gdk_screen_get_number (screen);
-
 	data = g_new (AppletFactoryData, 1);
 	data->task = task;
 	data->factory_id = factory_id;
-	data->parameters = g_variant_new ("(si*)", applet_id, screen_number, props);
+	data->parameters = g_variant_new ("(s*)", applet_id, props);
 	data->cancellable = cancellable ? g_object_ref (cancellable) : NULL;
 
 	bus_name = g_strdup_printf (PANEL_APPLET_BUS_NAME, factory_id);
@@ -519,7 +443,6 @@ panel_applet_container_get_applet (PanelAppletContainer *container,
 
 void
 panel_applet_container_add (PanelAppletContainer *container,
-			    GdkScreen            *screen,
 			    const gchar          *iid,
 			    GCancellable         *cancellable,
 			    GAsyncReadyCallback   callback,
@@ -531,7 +454,7 @@ panel_applet_container_add (PanelAppletContainer *container,
 
 	panel_applet_container_cancel_pending_operations (container);
 
-	panel_applet_container_get_applet (container, screen, iid, properties,
+	panel_applet_container_get_applet (container, iid, properties,
 					   cancellable, callback, user_data);
 }
 
