@@ -25,11 +25,6 @@
 #include "panel-icon-names.h"
 #include "panel-layout.h"
 #include "panel-schemas.h"
-#include "xstuff.h"
-
-/* globals */
-GSList *panels = NULL;
-GSList *panel_list = NULL;
 
 static gboolean  replace = FALSE;
 static gboolean  version = FALSE;
@@ -185,8 +180,6 @@ main (int argc, char **argv)
 		return 1;
 	}
 
-	xstuff_init ();
-
 	/* Flush to make sure our struts are seen by everyone starting
 	 * immediate after (eg, the nautilus desktop). */
 	gdk_flush ();
