@@ -39,7 +39,6 @@
 #include "panel-action-button.h"
 #include "panel-menu-button.h"
 #include "panel-menu-items.h"
-#include "panel-globals.h"
 #include "panel-run-dialog.h"
 #include "panel-lockdown.h"
 #include "panel-icon-names.h"
@@ -99,68 +98,6 @@ activate_app_def (GtkWidget      *menuitem,
 	panel_menu_item_activate_desktop_file (menuitem, path);
 }
 
-PanelWidget *
-menu_get_panel (GtkWidget *menu)
-{
-	PanelWidget *retval = NULL;
-
-	g_return_val_if_fail (menu != NULL, NULL);
-
-	if (GTK_IS_MENU_ITEM (menu))
-		menu = gtk_widget_get_parent (menu);
-
-	g_return_val_if_fail (GTK_IS_MENU (menu), NULL);
-
-	while (menu) {
-		retval = g_object_get_data (G_OBJECT (menu), "menu_panel");
-		if (retval)
-			break;
-
-		menu = gtk_widget_get_parent (gtk_menu_get_attach_widget (GTK_MENU (menu)));
-		if (!GTK_IS_MENU (menu))
-			break;
-	}
-
-	if (retval && !PANEL_IS_WIDGET (retval)) {
-		g_warning ("Invalid PanelWidget associated with menu");
-		retval = NULL;
-	}
-
-	if (!retval) {
-		g_warning ("Cannot find the PanelWidget associated with menu");
-		retval = panels->data;
-	}
-
-	return retval;
-}
-
-static void
-setup_menu_panel (GtkWidget *menu)
-{
-	PanelWidget *panel;
-
-	panel = g_object_get_data (G_OBJECT (menu), "menu_panel");
-	if (panel)
-		return;
-
-	panel = menu_get_panel (menu);
-	g_object_set_data (G_OBJECT (menu), "menu_panel", panel);
-
-	if (panel)
-		gtk_menu_set_screen (GTK_MENU (menu),
-				     gtk_widget_get_screen (GTK_WIDGET (panel)));
-}
-
-GdkScreen *
-menuitem_to_screen (GtkWidget *menuitem)
-{
-	PanelWidget *panel_widget;
-
-	panel_widget = menu_get_panel (menuitem);
-
-	return gtk_window_get_screen (GTK_WINDOW (panel_widget->toplevel));
-}
-
 static void
 reload_image_menu_items (void)
 {
@@ -220,8 +157,6 @@ create_empty_menu (void)
 
 	retval = panel_create_menu ();
 
-	g_signal_connect (retval, "show", G_CALLBACK (setup_menu_panel), NULL);
-
 	/* intercept all right button clicks makes sure they don't
 	   go to the object itself */
 	g_signal_connect (retval, "button_press_event",
@@ -764,8 +699,7 @@ submenu_to_display (GtkWidget *menu)
 	GMenuTree           *tree;
 	GMenuTreeDirectory  *directory;
 	const char          *menu_path;
-	void               (*append_callback) (GtkWidget *, gpointer);
-	gpointer             append_data;
+	void               (*append_callback) (GtkWidget *);
 
 	if (!g_object_get_data (G_OBJECT (menu), "panel-menu-needs-loading"))
 		return;
@@ -798,10 +732,9 @@ submenu_to_display (GtkWidget *menu)
 
 	append_callback = g_object_get_data (G_OBJECT (menu),
 					     "panel-menu-append-callback");
-	append_data     = g_object_get_data (G_OBJECT (menu),
-					     "panel-menu-append-callback-data");
+
 	if (append_callback)
-		append_callback (menu, append_data);
+		append_callback (menu);
 }
 
 static gboolean
@@ -878,15 +811,8 @@ create_submenu_entry (GtkWidget          *menu,
 		      GMenuTreeDirectory *directory)
 {
 	GtkWidget *menuitem;
-	gboolean   force_categories_icon;
 
-	force_categories_icon = g_object_get_data (G_OBJECT (menu),
-						   "panel-menu-force-icon-for-categories") != NULL;
-
-	if (force_categories_icon)
-		menuitem = panel_image_menu_item_new2 ();
-	else
-		menuitem = panel_image_menu_item_new ();
+	menuitem = panel_image_menu_item_new2 ();
 
 	panel_load_menu_image_deferred (menuitem,
 					panel_menu_icon_get_size (),
@@ -913,7 +839,6 @@ create_submenu (GtkWidget          *menu,
 {
 	GtkWidget *menuitem;
 	GtkWidget *submenu;
-	gboolean   force_categories_icon;
 
 	if (alias_directory)
 		menuitem = create_submenu_entry (menu, alias_directory);
@@ -923,13 +848,6 @@ create_submenu (GtkWidget          *menu,
 	submenu = create_fake_menu (directory);
 
 	gtk_menu_item_set_submenu (GTK_MENU_ITEM (menuitem), submenu);
-
-	/* Keep the infor that we force (or not) the icons to be visible */
-	force_categories_icon = g_object_get_data (G_OBJECT (menu),
-						   "panel-menu-force-icon-for-categories") != NULL;
-	g_object_set_data (G_OBJECT (submenu),
-			   "panel-menu-force-icon-for-categories",
-			   GINT_TO_POINTER (force_categories_icon));
 }
 
 static void 
@@ -1090,8 +1008,7 @@ remove_gmenu_tree_monitor (GtkWidget *menu,
 
 GtkWidget *
 create_applications_menu (const char *menu_file,
-			  const char *menu_path,
-			  gboolean    always_show_image)
+                          const char *menu_path)
 {
 	GMenuTree *tree;
 	GtkWidget *menu;
@@ -1099,12 +1016,6 @@ create_applications_menu (const char *menu_file,
 	GError *error = NULL;
 
 	menu = create_empty_menu ();
-
-	if (always_show_image)
-		g_object_set_data (G_OBJECT (menu),
-				   "panel-menu-force-icon-for-categories",
-				   GINT_TO_POINTER (TRUE));
-
 	tree = gmenu_tree_new (menu_file, GMENU_TREE_FLAGS_SORT_DISPLAY_NAME);
 
 	if (!gmenu_tree_load_sync (tree, &error)) {
@@ -1228,17 +1139,13 @@ setup_menu_item_with_icon (GtkWidget   *item,
 }
 
 static void
-main_menu_append (GtkWidget *main_menu,
-		  gpointer   data)
+main_menu_append (GtkWidget *main_menu)
 {
-	PanelWidget *panel;
 	GtkWidget   *item;
 	gboolean     add_separator;
 	GList       *children;
 	GList       *last;
 
-	panel = PANEL_WIDGET (data);
-
 	add_separator = FALSE;
 	children = gtk_container_get_children (GTK_CONTAINER (main_menu));
 	last = g_list_last (children);
@@ -1251,12 +1158,10 @@ main_menu_append (GtkWidget *main_menu,
 		add_menu_separator (main_menu);
 
 	item = panel_place_menu_item_new (TRUE, FALSE);
-	panel_place_menu_item_set_panel (item, panel);
 	gtk_menu_shell_append (GTK_MENU_SHELL (main_menu), item);
 	gtk_widget_show (item);
 
 	item = panel_desktop_menu_item_new (TRUE, FALSE, FALSE);
-	panel_desktop_menu_item_set_panel (item, panel);
 	gtk_menu_shell_append (GTK_MENU_SHELL (main_menu), item);
 	gtk_widget_show (item);
 
@@ -1270,18 +1175,12 @@ create_main_menu (PanelWidget *panel)
 	gchar *applications_menu;
 
 	applications_menu = get_applications_menu ();
-	main_menu = create_applications_menu (applications_menu, NULL, TRUE);
+	main_menu = create_applications_menu (applications_menu, NULL);
 	g_free (applications_menu);
 
-	g_object_set_data (G_OBJECT (main_menu), "menu_panel", panel);
-	/* FIXME need to update the panel on parent_set */
-
 	g_object_set_data (G_OBJECT (main_menu),
 			   "panel-menu-append-callback",
 			   main_menu_append);
-	g_object_set_data (G_OBJECT (main_menu),
-			   "panel-menu-append-callback-data",
-			   panel);
 
 	return main_menu;
 }
