@@ -40,8 +40,7 @@ void            setup_menu_item_with_icon (GtkWidget        *item,
 
 GtkWidget      *create_empty_menu         (void);
 GtkWidget      *create_applications_menu  (const char  *menu_file,
-					   const char  *menu_path,
-					   gboolean    always_show_image);
+                                           const char  *menu_path);
 GtkWidget      *create_main_menu          (PanelWidget *panel);
 
 void		setup_internal_applet_drag (GtkWidget             *menuitem,
@@ -60,8 +59,6 @@ GdkPixbuf *	panel_make_menu_icon (GtkIconTheme *icon_theme,
 				      int           size,
 				      gboolean     *long_operation);
 
-GdkScreen      *menuitem_to_screen   (GtkWidget *menuitem);
-PanelWidget    *menu_get_panel       (GtkWidget *menu);
 GtkWidget      *add_menu_separator   (GtkWidget *menu);
 
 gboolean menu_dummy_button_press_event (GtkWidget      *menuitem,
