@@ -42,8 +42,6 @@
 #include "panel-typebuiltins.h"
 #include "panel-force-quit.h"
 #include "panel-util.h"
-#include "panel-session.h"
-#include "panel-globals.h"
 #include "panel-run-dialog.h"
 #include "panel-a11y.h"
 #include "panel-layout.h"
@@ -79,7 +77,6 @@ static PanelEnumStringPair panel_action_type_map [] = {
 	{ PANEL_ACTION_RUN,            "run"            },
 	{ PANEL_ACTION_SEARCH,         "search"         },
 	{ PANEL_ACTION_FORCE_QUIT,     "force-quit"     },
-	{ PANEL_ACTION_CONNECT_SERVER, "connect-server" },
 	{ PANEL_ACTION_HIBERNATE,      "hibernate"      },
 	{ PANEL_ACTION_SUSPEND,        "suspend"        },
 	{ PANEL_ACTION_HYBRID_SLEEP,   "hybrid-sleep"   },
@@ -332,54 +329,12 @@ panel_action_force_quit (GtkWidget *widget)
 			  gtk_get_current_event_time ());
 }
 
-/* Connect Server
- */
-static void
-panel_action_connect_server (GtkWidget *widget)
-{
-	GdkScreen *screen;
-	GAppInfo  *app_info;
-	GError    *error;
-
-	screen = gtk_widget_get_screen (GTK_WIDGET (widget));
-	error = NULL;
-	app_info = g_app_info_create_from_commandline ("nautilus-connect-server",
-						       _("Connect to server"),
-						       G_APP_INFO_CREATE_NONE,
-						       &error);
-
-	if (!error) {
-		GdkAppLaunchContext *launch_context;
-		GdkDisplay          *display;
-
-		display = gdk_screen_get_display (screen);
-		launch_context = gdk_display_get_app_launch_context (display);
-		gdk_app_launch_context_set_screen (launch_context, screen);
-
-		g_app_info_launch (app_info, NULL,
-				   G_APP_LAUNCH_CONTEXT (launch_context),
-				   &error);
-
-		g_object_unref (launch_context);
-		g_object_unref (app_info);
-	}
-
-	if (error) {
-		panel_error_dialog (NULL, screen,
-				    "cannot_connect_server",
-				    TRUE,
-				    _("Could not connect to server"),
-				    error->message);
-		g_clear_error (&error);
-	}
-}
-
 typedef struct {
 	PanelActionButtonType   type;
-	char                   *icon_name;
-	char                   *text;
-	char                   *tooltip;
-	char                   *drag_id;
+	const gchar            *icon_name;
+	const gchar            *text;
+	const gchar            *tooltip;
+	const gchar            *drag_id;
 	void                  (*invoke)      (GtkWidget         *widget);
 	void                  (*setup_menu)  (PanelActionButton *button);
 	void                  (*invoke_menu) (PanelActionButton *button,
@@ -444,14 +399,6 @@ static PanelAction actions [] = {
 		panel_action_force_quit, NULL, NULL,
 		panel_lockdown_get_disable_force_quit_s
 	},
-	{
-		PANEL_ACTION_CONNECT_SERVER,
-		PANEL_ICON_REMOTE, //FIXME icon
-		N_("Connect to Server..."),
-		N_("Connect to a remote computer or shared disk"),
-		"ACTION:connect-server:NEW",
-		panel_action_connect_server, NULL, NULL, NULL
-	},
 	{
 		PANEL_ACTION_HIBERNATE,
 		PANEL_ICON_HIBERNATE,
@@ -499,22 +446,11 @@ static PanelAction actions [] = {
 	}
 };
 
-static gboolean
-panel_action_get_is_deprecated (PanelActionButtonType type)
-{
-	g_return_val_if_fail (type > PANEL_ACTION_NONE && type < PANEL_ACTION_LAST, FALSE);
-
-	return (type > PANEL_ACTION_LAST_NON_DEPRECATED);
-}
-
 gboolean
 panel_action_get_is_disabled (PanelActionButtonType type)
 {
 	g_return_val_if_fail (type > PANEL_ACTION_NONE && type < PANEL_ACTION_LAST, FALSE);
 
-	if (panel_action_get_is_deprecated (type))
-		return TRUE;
-
 	if (actions [type].is_disabled)
 		return actions [type].is_disabled ();
 
@@ -732,9 +668,6 @@ panel_action_button_set_type (PanelActionButton     *button,
 {
 	g_return_if_fail (type > PANEL_ACTION_NONE && type < PANEL_ACTION_LAST);
 
-	if (panel_action_get_is_deprecated (type))
-		return;
-
 	if (type == button->priv->type)
 		return;
 
@@ -824,7 +757,8 @@ panel_action_button_load (PanelWidget *panel,
 	}
 
 	if (type == PANEL_ACTION_NONE) {
-		g_warning ("Unknown action type '%s", detail_for_type);
+		g_debug ("Unknown action type '%s'", detail_for_type);
+		panel_layout_delete_object (id);
 		return;
 	}
 
@@ -874,9 +808,6 @@ panel_action_button_load_from_drag (PanelToplevel       *toplevel,
 
 	g_return_val_if_fail (type > PANEL_ACTION_NONE && type < PANEL_ACTION_LAST, FALSE);
 
-	if (panel_action_get_is_deprecated (type))
-		return retval;
-
 	if (strcmp (elements [2], "NEW")) {
 		*old_applet_idx = strtol (elements [2], NULL, 10);
 		retval = TRUE; /* Remove the old applet */
@@ -905,7 +836,7 @@ panel_action_button_set_dnd_enabled (PanelActionButton *button,
 
 	if (enabled) {
 		static GtkTargetEntry dnd_targets [] = {
-			{ "application/x-panel-applet-internal", 0, 0 }
+			{ (gchar *) "application/x-panel-applet-internal", 0, 0 }
 		};
 
 		gtk_widget_set_has_window (GTK_WIDGET (button), TRUE);
