@@ -24,6 +24,7 @@
 #include <string.h>
 
 #include <glib/gi18n.h>
+#include <gdk/gdkx.h>
 
 #include <gmenu-tree.h>
 
@@ -36,10 +37,8 @@
 #include "panel-applet-frame.h"
 #include "panel-action-button.h"
 #include "panel-menu-bar.h"
-#include "panel-separator.h"
 #include "panel-toplevel.h"
 #include "panel-menu-button.h"
-#include "panel-globals.h"
 #include "panel-layout.h"
 #include "panel-lockdown.h"
 #include "panel-util.h"
@@ -90,7 +89,6 @@ typedef enum {
 	PANEL_ADDTO_LAUNCHER_NEW,
 	PANEL_ADDTO_MENU,
 	PANEL_ADDTO_MENUBAR,
-	PANEL_ADDTO_SEPARATOR,
 	PANEL_ADDTO_USER_MENU
 } PanelAddtoItemType;
 
@@ -155,15 +153,6 @@ prepend_internal_applets (GSList *list)
 	internal->iid = g_strdup ("MENUBAR:NEW");
 	list = g_slist_prepend (list, internal);
 
-	internal = g_new0 (PanelAddtoItemInfo, 1);
-	internal->type = PANEL_ADDTO_SEPARATOR;
-	internal->name = g_strdup (_("Separator"));
-	internal->description = g_strdup (_("A separator to organize the panel items"));
-	internal->icon = g_themed_icon_new (PANEL_ICON_SEPARATOR);
-	internal->action_type = PANEL_ACTION_NONE;
-	internal->iid = g_strdup ("SEPARATOR:NEW");
-	list = g_slist_prepend (list, internal);
-
 	internal = g_new0 (PanelAddtoItemInfo, 1);
 	internal->type = PANEL_ADDTO_USER_MENU;
 	internal->name = g_strdup (_("User menu"));
@@ -768,11 +757,6 @@ panel_addto_add_item (PanelAddtoDialog   *dialog,
 				       dialog->insert_pack_type,
 				       pack_index);
 		break;
-	case PANEL_ADDTO_SEPARATOR:
-		panel_separator_create (dialog->panel_widget->toplevel,
-					dialog->insert_pack_type,
-					pack_index);
-		break;
 	case PANEL_ADDTO_USER_MENU:
 		panel_user_menu_create (dialog->panel_widget->toplevel,
 					dialog->insert_pack_type,
@@ -1256,13 +1240,13 @@ panel_addto_present (GtkMenuItem *item,
 {
 	PanelAddtoDialog *dialog;
 	PanelToplevel *toplevel;
-	PanelData     *pd;
+	PanelObjectPackType insert_pack_type;
+	GdkEvent *current_event;
 	GdkScreen *screen;
 	gint screen_height;
 	gint height;
 
 	toplevel = panel_widget->toplevel;
-	pd = g_object_get_data (G_OBJECT (toplevel), "PanelData");
 
 	if (!panel_addto_dialog_quark)
 		panel_addto_dialog_quark =
@@ -1280,7 +1264,17 @@ panel_addto_present (GtkMenuItem *item,
 		panel_addto_present_applets (dialog);
 	}
 
-	dialog->insert_pack_type = pd ? pd->insert_pack_type : PANEL_OBJECT_PACK_START;
+	insert_pack_type = PANEL_OBJECT_PACK_START;
+	current_event = gtk_get_current_event ();
+
+	if (current_event != NULL) {
+		if (current_event->type == GDK_BUTTON_PRESS)
+			insert_pack_type = panel_widget_get_insert_pack_type_at_cursor (panel_widget);
+
+		gdk_event_free (current_event);
+	}
+
+	dialog->insert_pack_type = insert_pack_type;
 	gtk_window_set_screen (GTK_WINDOW (dialog), screen);
 	gtk_window_set_default_size (GTK_WINDOW (dialog),
 				     height * 8 / 7, height);
