@@ -28,22 +28,20 @@
 #include <glib/gi18n.h>
 
 #include <gdk/gdk.h>
+#include <gdk/gdkkeysyms.h>
 #include <gdk/gdkx.h>
 
 #include "panel-applets-manager.h"
 #include "panel-bindings.h"
 #include "panel.h"
 #include "applet.h"
-#include "panel-marshal.h"
-#include "panel-background.h"
 #include "panel-layout.h"
 #include "panel-lockdown.h"
 #include "panel-object-loader.h"
 #include "panel-schemas.h"
 #include "panel-stock-icons.h"
-#include "xstuff.h"
-#include "panel-compatibility.h"
 
+#include <libpanel-applet-private/panel-applet-frame-dbus.h>
 #include "panel-applet-frame.h"
 
 #define PANEL_RESPONSE_DELETE      0
@@ -56,11 +54,6 @@ static void panel_applet_frame_loading_failed  (const char  *iid,
 					        PanelWidget *panel,
 					        const char  *id);
 
-static void panel_applet_frame_load_helper     (const gchar *iid,
-						PanelWidget *panel,
-						const char  *id,
-						GSettings   *settings);
-
 struct _PanelAppletFrameActivating {
 	PanelWidget *panel;
 	char        *id;
@@ -87,8 +80,17 @@ struct _PanelAppletFramePrivate {
 	GdkRectangle     handle_rect;
 
 	guint            has_handle : 1;
+
+	gboolean         moving_focus_out;
 };
 
+enum {
+	MOVE_FOCUS_OUT_OF_APPLET,
+	LAST_SIGNAL
+};
+
+static guint panel_applet_frame_signals [LAST_SIGNAL];
+
 static gboolean
 panel_applet_frame_draw (GtkWidget *widget,
                          cairo_t   *cr)
@@ -97,7 +99,6 @@ panel_applet_frame_draw (GtkWidget *widget,
 	GtkStyleContext *context;
 	GtkStateFlags     state;
 	cairo_pattern_t  *bg_pattern;
-	PanelBackground  *background;
 
         if (GTK_WIDGET_CLASS (panel_applet_frame_parent_class)->draw)
                 GTK_WIDGET_CLASS (panel_applet_frame_parent_class)->draw (widget, cr);
@@ -117,10 +118,8 @@ panel_applet_frame_draw (GtkWidget *widget,
 	gtk_style_context_get (context, state,
 			       "background-image", &bg_pattern,
 			       NULL);
-	background = &frame->priv->panel->toplevel->background;
 
-	if (bg_pattern && (background->type == PANEL_BACK_IMAGE ||
-	    (background->type == PANEL_BACK_COLOR && background->has_alpha))) {
+	if (bg_pattern) {
 		cairo_matrix_t ptm;
 
 		cairo_matrix_init_translate (&ptm,
@@ -224,25 +223,6 @@ panel_applet_frame_get_preferred_height(GtkWidget *widget, gint *minimal_height,
 	}
 }
 
-static void
-change_background (PanelAppletFrame *frame,
-                   GtkAllocation    *old,
-                   GtkAllocation    *new)
-{
-	PanelBackgroundType type;
-
-	if (old->x == new->x &&
-	    old->y == new->y &&
-	    old->width == new->width &&
-	    old->height == new->height)
-		return;
-
-	type = frame->priv->panel->toplevel->background.type;
-
-	PANEL_APPLET_FRAME_GET_CLASS (frame)->change_background (frame,
-	                                                         type);
-}
-
 static void
 panel_applet_frame_size_allocate (GtkWidget     *widget,
 				  GtkAllocation *allocation)
@@ -262,12 +242,10 @@ panel_applet_frame_size_allocate (GtkWidget     *widget,
 	if (!frame->priv->has_handle) {
 		GTK_WIDGET_CLASS (panel_applet_frame_parent_class)->size_allocate (widget,
 										   allocation);
-		change_background (frame, &widget_allocation, allocation);
 		return;
 	}
 
 	gtk_widget_set_allocation (widget, allocation);
-	change_background (frame, &widget_allocation, allocation);
 
 	frame->priv->handle_rect.x = 0;
 	frame->priv->handle_rect.y = 0;
@@ -357,19 +335,17 @@ panel_applet_frame_button_changed (GtkWidget      *widget,
 				   GdkEventButton *event)
 {
 	PanelAppletFrame *frame;
-	gboolean          handled = FALSE;
 	guint             modifiers;
-	GdkDisplay       *display;
-	GdkDevice        *pointer;
-	GdkDeviceManager *device_manager;
 
 	frame = PANEL_APPLET_FRAME (widget);
 
-	if (!frame->priv->has_handle)
-		return handled;
+	if (PANEL_IS_APPLET_FRAME_DBUS (frame)) {
+		if (!frame->priv->has_handle)
+			return FALSE;
 
-	if (event->window != gtk_widget_get_window (widget))
-		return FALSE;
+		if (event->window != gtk_widget_get_window (widget))
+			return FALSE;
+	}
 
 	modifiers = event->state & gtk_accelerator_get_default_mod_mask ();
 
@@ -383,20 +359,22 @@ panel_applet_frame_button_changed (GtkWidget      *widget,
 				panel_widget_applet_drag_start (
 					frame->priv->panel, GTK_WIDGET (frame),
 					event->time);
-				handled = TRUE;
+				return TRUE;
 			} else if (event->type == GDK_BUTTON_RELEASE) {
 				panel_widget_applet_drag_end (frame->priv->panel);
-				handled = TRUE;
+				return TRUE;
 			}
 		}
 		break;
 	case 3:
 		if (event->type == GDK_BUTTON_PRESS ||
 		    event->type == GDK_2BUTTON_PRESS) {
+			GdkDisplay *display;
+			GdkSeat *seat;
+
 			display = gtk_widget_get_display (widget);
-			device_manager = gdk_display_get_device_manager (display);
-			pointer = gdk_device_manager_get_client_pointer (device_manager);
-			gdk_device_ungrab (pointer, GDK_CURRENT_TIME);
+			seat = gdk_display_get_default_seat (display);
+			gdk_seat_ungrab (seat);
 
 			if (modifiers == panel_bindings_get_mouse_button_modifier_keymask ())
 				PANEL_APPLET_FRAME_GET_CLASS (frame)->popup_edit_menu (frame,
@@ -407,15 +385,15 @@ panel_applet_frame_button_changed (GtkWidget      *widget,
 										  event->button,
 										  event->time);
 
-			handled = TRUE;
+			return TRUE;
 		} else if (event->type == GDK_BUTTON_RELEASE)
-			handled = TRUE;
+			return TRUE;
 		break;
 	default:
 		break;
 	}
 
-	return handled;
+	return FALSE;
 }
 
 static void
@@ -431,11 +409,55 @@ panel_applet_frame_finalize (GObject *object)
         G_OBJECT_CLASS (panel_applet_frame_parent_class)->finalize (object);
 }
 
+static void
+panel_applet_frame_move_focus_out_of_applet (PanelAppletFrame *frame,
+                                             GtkDirectionType  dir)
+{
+	GtkWidget *toplevel;
+
+	frame->priv->moving_focus_out = TRUE;
+	toplevel = gtk_widget_get_toplevel (GTK_WIDGET (frame));
+	g_return_if_fail (toplevel);
+
+	gtk_widget_child_focus (toplevel, dir);
+	frame->priv->moving_focus_out = FALSE;
+}
+
+static gboolean
+panel_applet_frame_focus (GtkWidget        *widget,
+                          GtkDirectionType  dir)
+{
+	PanelAppletFrame *frame;
+
+	g_return_val_if_fail (PANEL_IS_APPLET_FRAME (widget), FALSE);
+
+	frame = PANEL_APPLET_FRAME (widget);
+
+	if (frame->priv->moving_focus_out)
+		return FALSE;
+
+	return GTK_WIDGET_CLASS (panel_applet_frame_parent_class)->focus (widget, dir);
+}
+
+static void
+add_tab_bindings (GtkBindingSet    *binding_set,
+                  GdkModifierType   modifiers,
+                  GtkDirectionType  direction)
+{
+	gtk_binding_entry_add_signal (binding_set, GDK_KEY_Tab, modifiers,
+				      "move_focus_out_of_applet", 1,
+				      GTK_TYPE_DIRECTION_TYPE, direction);
+	gtk_binding_entry_add_signal (binding_set, GDK_KEY_KP_Tab, modifiers,
+				      "move_focus_out_of_applet", 1,
+				      GTK_TYPE_DIRECTION_TYPE, direction);
+}
+
 static void
 panel_applet_frame_class_init (PanelAppletFrameClass *klass)
 {
 	GObjectClass   *gobject_class = (GObjectClass *) klass;
 	GtkWidgetClass *widget_class = (GtkWidgetClass *) klass;
+	GtkBindingSet *binding_set;
 
 	gobject_class->finalize = panel_applet_frame_finalize;
 
@@ -445,6 +467,22 @@ panel_applet_frame_class_init (PanelAppletFrameClass *klass)
 	widget_class->size_allocate        = panel_applet_frame_size_allocate;
 	widget_class->button_press_event   = panel_applet_frame_button_changed;
 	widget_class->button_release_event = panel_applet_frame_button_changed;
+	widget_class->focus                = panel_applet_frame_focus;
+
+	klass->move_focus_out_of_applet = panel_applet_frame_move_focus_out_of_applet;
+
+	panel_applet_frame_signals [MOVE_FOCUS_OUT_OF_APPLET] =
+                g_signal_new ("move_focus_out_of_applet",
+                              G_TYPE_FROM_CLASS (klass), G_SIGNAL_RUN_LAST | G_SIGNAL_ACTION,
+                              G_STRUCT_OFFSET (PanelAppletFrameClass, move_focus_out_of_applet),
+                              NULL, NULL, NULL,
+                              G_TYPE_NONE, 1, GTK_TYPE_DIRECTION_TYPE);
+
+	binding_set = gtk_binding_set_by_class (gobject_class);
+	add_tab_bindings (binding_set, 0, GTK_DIR_TAB_FORWARD);
+	add_tab_bindings (binding_set, GDK_SHIFT_MASK, GTK_DIR_TAB_BACKWARD);
+	add_tab_bindings (binding_set, GDK_CONTROL_MASK, GTK_DIR_TAB_FORWARD);
+	add_tab_bindings (binding_set, GDK_CONTROL_MASK | GDK_SHIFT_MASK, GTK_DIR_TAB_BACKWARD);
 
 	g_type_class_add_private (klass, sizeof (PanelAppletFramePrivate));
 }
@@ -598,7 +636,7 @@ _panel_applet_frame_update_size_hints (PanelAppletFrame *frame,
 {
 	if (frame->priv->has_handle) {
 		gint extra_size = HANDLE_SIZE + 1;
-		gint i;
+		guint i;
 
 		for (i = 0; i < n_elements; i++)
 			size_hints[i] += extra_size;
@@ -611,159 +649,6 @@ _panel_applet_frame_update_size_hints (PanelAppletFrame *frame,
 					    n_elements);
 }
 
-char *
-_panel_applet_frame_get_background_string (PanelAppletFrame    *frame,
-					   PanelWidget         *panel,
-					   PanelBackgroundType  type)
-{
-	GtkAllocation allocation;
-	int x;
-	int y;
-
-	gtk_widget_get_allocation (GTK_WIDGET (frame), &allocation);
-
-	x = allocation.x;
-	y = allocation.y;
-
-	if (frame->priv->has_handle) {
-		switch (frame->priv->orientation) {
-		case PANEL_ORIENTATION_TOP:
-		case PANEL_ORIENTATION_BOTTOM:
-			if (gtk_widget_get_direction (GTK_WIDGET (frame)) !=
-			    GTK_TEXT_DIR_RTL)
-				x += frame->priv->handle_rect.width;
-			break;
-		case PANEL_ORIENTATION_LEFT:
-		case PANEL_ORIENTATION_RIGHT:
-			y += frame->priv->handle_rect.height;
-			break;
-		default:
-			g_assert_not_reached ();
-			break;
-		}
-	}
-
-	return panel_background_make_string (&panel->toplevel->background, x, y);
-}
-
-static void
-panel_applet_frame_reload_response (GtkWidget        *dialog,
-				    int               response,
-				    PanelAppletFrame *frame)
-{
-	AppletInfo *info;
-
-	g_return_if_fail (PANEL_IS_APPLET_FRAME (frame));
-
-	if (!frame->priv->iid || !frame->priv->panel) {
-		g_object_unref (frame);
-		gtk_widget_destroy (dialog);
-		return;
-	}
-
-	info = frame->priv->applet_info;
-
-	if (response == PANEL_RESPONSE_RELOAD) {
-		PanelWidget *panel;
-		char        *iid;
-		char        *id = NULL;
-		GSettings   *settings = NULL;
-
-		panel = frame->priv->panel;
-		iid   = g_strdup (frame->priv->iid);
-
-		if (info) {
-			id = g_strdup (info->id);
-			settings = panel_applet_get_settings (info);
-			g_object_ref (settings);
-			panel_applet_clean (info);
-		}
-
-		panel_applet_frame_load_helper (iid, panel, id, settings);
-
-		g_free (iid);
-		g_free (id);
-		if (settings)
-			g_object_unref (settings);
-
-	} else if (response == PANEL_RESPONSE_DELETE) {
-		/* if we can't write to applets list we can't really delete
-		   it, so we'll just ignore this.  FIXME: handle this
-		   more correctly I suppose. */
-		if (panel_layout_is_writable () && info)
-			panel_layout_delete_object (panel_applet_get_id (info));
-	}
-
-	g_object_unref (frame);
-	gtk_widget_destroy (dialog);
-}
-
-void
-_panel_applet_frame_applet_broken (PanelAppletFrame *frame)
-{
-	GtkWidget  *dialog;
-	GdkScreen  *screen;
-	const char *applet_name = NULL;
-	char       *dialog_txt;
-
-	screen = gtk_widget_get_screen (GTK_WIDGET (frame));
-
-	if (xstuff_is_display_dead ())
-		return;
-
-	if (frame->priv->iid) {
-		PanelAppletInfo *info;
-
-		info = (PanelAppletInfo *)panel_applets_manager_get_applet_info (frame->priv->iid);
-		applet_name = panel_applet_info_get_name (info);
-	}
-
-	if (applet_name)
-		dialog_txt = g_strdup_printf (_("\"%s\" has quit unexpectedly"), applet_name);
-	else
-		dialog_txt = g_strdup (_("Panel object has quit unexpectedly"));
-
-	dialog = gtk_message_dialog_new (NULL, GTK_DIALOG_DESTROY_WITH_PARENT,
-					 GTK_MESSAGE_WARNING, GTK_BUTTONS_NONE,
-					 dialog_txt, applet_name ? applet_name : NULL);
-
-	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
-						  _("If you reload a panel object, it will automatically "
-						    "be added back to the panel."));
-
-	gtk_container_set_border_width (GTK_CONTAINER (dialog), 6);
-
-	if (panel_layout_is_writable ()) {
-		gtk_dialog_add_buttons (GTK_DIALOG (dialog),
-		                        _("D_elete"), PANEL_RESPONSE_DELETE,
-		                        _("_Don't Reload"), PANEL_RESPONSE_DONT_RELOAD,
-		                        _("_Reload"), PANEL_RESPONSE_RELOAD,
-		                        NULL);
-	} else {
-		gtk_dialog_add_buttons (GTK_DIALOG (dialog),
-		                        _("_Don't Reload"), PANEL_RESPONSE_DONT_RELOAD,
-		                        _("_Reload"), PANEL_RESPONSE_RELOAD,
-		                        NULL);
-	}
-
-	gtk_dialog_set_default_response (GTK_DIALOG (dialog),
-	                                 PANEL_RESPONSE_RELOAD);
-
-	gtk_window_set_screen (GTK_WINDOW (dialog), screen);
-
-	g_signal_connect (dialog, "response",
-			  G_CALLBACK (panel_applet_frame_reload_response),
-			  g_object_ref (frame));
-
-	panel_widget_register_open_dialog (frame->priv->panel, dialog);
-	gtk_window_set_urgency_hint (GTK_WINDOW (dialog), TRUE);
-	/* FIXME: http://bugzilla.gnome.org/show_bug.cgi?id=165132 */
-	gtk_window_set_title (GTK_WINDOW (dialog), _("Error"));
-
-	gtk_widget_show (dialog);
-	g_free (dialog_txt);
-}
-
 void
 _panel_applet_frame_applet_remove (PanelAppletFrame *frame)
 {
@@ -809,12 +694,6 @@ panel_applet_frame_activating_free (PanelAppletFrameActivating *frame_act)
 	g_slice_free (PanelAppletFrameActivating, frame_act);
 }
 
-GdkScreen *
-panel_applet_frame_activating_get_screen (PanelAppletFrameActivating *frame_act)
-{
-	return gtk_widget_get_screen (GTK_WIDGET (frame_act->panel));
-}
-
 PanelOrientation
 panel_applet_frame_activating_get_orientation (PanelAppletFrameActivating *frame_act)
 {
@@ -935,10 +814,6 @@ panel_applet_frame_load_helper (const gchar *iid,
 {
 	PanelAppletFrameActivating *frame_act;
 
-	g_return_if_fail (iid != NULL);
-	g_return_if_fail (panel != NULL);
-	g_return_if_fail (id != NULL);
-
 	if (g_slist_find_custom (no_reload_applets, id,
 				 (GCompareFunc) strcmp)) {
 		panel_object_loader_stop_loading (id);
@@ -971,14 +846,22 @@ panel_applet_frame_load (PanelWidget *panel_widget,
 	g_return_if_fail (panel_widget != NULL);
 	g_return_if_fail (id != NULL);
 
-	applet_iid = panel_compatibility_get_applet_iid (settings, id);
-	if (!applet_iid) {
-		panel_object_loader_stop_loading (id);
-		return;
+	applet_iid = g_settings_get_string (settings, PANEL_OBJECT_IID_KEY);
+
+	if (!panel_applets_manager_get_applet_info (applet_iid)) {
+		gchar *new_iid;
+
+		new_iid = panel_applets_manager_get_new_iid (applet_iid);
+
+		if (new_iid != NULL) {
+			g_settings_set_string (settings, PANEL_OBJECT_IID_KEY, new_iid);
+			g_free (applet_iid);
+
+			applet_iid = new_iid;
+		}
 	}
 
 	panel_applet_frame_load_helper (applet_iid, panel_widget, id, settings);
-
 	g_free (applet_iid);
 }
 
@@ -995,3 +878,12 @@ panel_applet_frame_create (PanelToplevel       *toplevel,
 				    panel_toplevel_get_id (toplevel),
 				    pack_type, pack_index);
 }
+
+gboolean
+_panel_applet_frame_get_can_move (PanelAppletFrame *frame)
+{
+	if (!frame->priv->applet_info)
+		return FALSE;
+
+	return panel_applet_can_freely_move (frame->priv->applet_info);
+}
