@@ -22,10 +22,10 @@
 
 #include <gio/gio.h>
 
+#include <libpanel-applet-private/gp-applet-manager.h>
+#include <libpanel-applet-private/panel-applets-manager-dbus.h>
 #include <libpanel-util/panel-cleanup.h>
 
-#include "panel-modules.h"
-
 #include "panel-applets-manager.h"
 
 G_DEFINE_ABSTRACT_TYPE (PanelAppletsManager, panel_applets_manager, G_TYPE_OBJECT)
@@ -55,35 +55,18 @@ _panel_applets_manager_cleanup (gpointer data)
 static void
 _panel_applets_managers_ensure_loaded (void)
 {
-	GIOExtensionPoint *point;
-	GList             *extensions, *l;
+	GObject *manager;
 
 	if (panel_applets_managers != NULL)
 		return;
 
 	panel_cleanup_register (PANEL_CLEAN_FUNC (_panel_applets_manager_cleanup), NULL);
 
-	panel_modules_ensure_loaded ();
+	manager = g_object_new (PANEL_TYPE_APPLETS_MANAGER_DBUS, NULL);
+	panel_applets_managers = g_slist_append (panel_applets_managers, manager);
 
-	point = g_io_extension_point_lookup (PANEL_APPLETS_MANAGER_EXTENSION_POINT_NAME);
-
-	extensions = g_io_extension_point_get_extensions (point);
-
-	if (extensions == NULL)
-		g_error ("No PanelAppletsManager implementations exist.");
-
-	for (l = extensions; l != NULL; l = l->next) {
-		GIOExtension *extension;
-		GType         type;
-		GObject      *object;
-
-		extension = l->data;
-		type = g_io_extension_get_type (extension);
-		object = g_object_new (type, NULL);
-		panel_applets_managers = g_slist_prepend (panel_applets_managers, object);
-	}
-
-	panel_applets_managers = g_slist_reverse (panel_applets_managers);
+	manager = g_object_new (GP_TYPE_APPLET_MANAGER, NULL);
+	panel_applets_managers = g_slist_append (panel_applets_managers, manager);
 }
 
 GList *
@@ -158,26 +141,6 @@ panel_applets_manager_get_applet_info (const gchar *iid)
 	return NULL;
 }
 
-PanelAppletInfo *
-panel_applets_manager_get_applet_info_from_old_id (const gchar *iid)
-{
-	GSList *l;
-	PanelAppletInfo *retval = NULL;
-
-	_panel_applets_managers_ensure_loaded ();
-
-	for (l = panel_applets_managers; l != NULL; l = l->next) {
-		PanelAppletsManager *manager = PANEL_APPLETS_MANAGER (l->data);
-
-		retval = PANEL_APPLETS_MANAGER_GET_CLASS (manager)->get_applet_info_from_old_id (manager, iid);
-
-		if (retval != NULL)
-			return retval;
-	}
-
-	return NULL;
-}
-
 gboolean
 panel_applets_manager_load_applet (const gchar                *iid,
 				   PanelAppletFrameActivating *frame_act)
@@ -197,3 +160,44 @@ panel_applets_manager_load_applet (const gchar                *iid,
 
 	return FALSE;
 }
+
+GtkWidget *
+panel_applets_manager_get_applet_widget (const gchar *iid,
+                                         guint        uid)
+{
+	GSList *l;
+
+	_panel_applets_managers_ensure_loaded ();
+
+	for (l = panel_applets_managers; l != NULL; l = l->next) {
+		PanelAppletsManager *manager = PANEL_APPLETS_MANAGER (l->data);
+
+		if (!PANEL_APPLETS_MANAGER_GET_CLASS (manager)->get_applet_info (manager, iid))
+			continue;
+
+		return PANEL_APPLETS_MANAGER_GET_CLASS (manager)->get_applet_widget (manager, iid, uid);
+	}
+
+	return NULL;
+}
+
+gchar *
+panel_applets_manager_get_new_iid (const gchar *old_iid)
+{
+	GSList *l;
+	PanelAppletsManager *manager;
+	gchar *new_iid;
+
+	_panel_applets_managers_ensure_loaded ();
+
+	for (l = panel_applets_managers; l != NULL; l = l->next) {
+		manager = PANEL_APPLETS_MANAGER (l->data);
+
+		new_iid = PANEL_APPLETS_MANAGER_GET_CLASS (manager)->get_new_iid (manager, old_iid);
+
+		if (new_iid != NULL)
+			return new_iid;
+	}
+
+	return NULL;
+}
