@@ -35,7 +35,6 @@
 #include <libpanel-util/panel-error.h>
 #include <libpanel-util/panel-show.h>
 
-#include "free-the-fish.h"
 #include "panel-util.h"
 #include "panel.h"
 #include "menu.h"
@@ -66,44 +65,16 @@ panel_context_menu_delete_panel (PanelToplevel *toplevel)
         panel_delete (toplevel);
 }
 
-static gboolean
-panel_context_menu_check_for_screen (GtkWidget *w,
-				     GdkEvent *ev,
-				     gpointer data)
-{
-	static int times = 0;
-	if (!w) {
-		times = 0;
-		return FALSE;
-	}
-	if (ev->type != GDK_KEY_PRESS)
-		return FALSE;
-	if (ev->key.keyval == GDK_KEY_f ||
-	    ev->key.keyval == GDK_KEY_F) {
-		times++;
-		if (times == 3) {
-			times = 0;
-			free_the_fish ();
-		}
-	}
-	return FALSE;
-}
-
 static void
-panel_context_menu_setup_delete_panel_item (GtkWidget *menu,
-					    GtkWidget *menuitem)
+panel_context_menu_setup_delete_panel_item (GtkWidget     *menuitem,
+                                            PanelToplevel *toplevel)
 {
-	PanelWidget *panel_widget;
 	gboolean     sensitive;
 
-	panel_context_menu_check_for_screen (NULL, NULL, NULL);
-
-	panel_widget = menu_get_panel (menu);
-
-	g_assert (PANEL_IS_TOPLEVEL (panel_widget->toplevel));
+	g_assert (PANEL_IS_TOPLEVEL (toplevel));
 
 	sensitive =
-		!panel_toplevel_is_last (panel_widget->toplevel) &&
+		!panel_toplevel_is_last (toplevel) &&
 		!panel_lockdown_get_panels_locked_down_s () &&
 		panel_layout_is_writable ();
 
@@ -174,9 +145,9 @@ panel_context_menu_build_edition (PanelWidget *panel_widget,
 	g_signal_connect_swapped (G_OBJECT (menuitem), "activate",
 				  G_CALLBACK (panel_context_menu_delete_panel),
 				  panel_widget->toplevel);
-	g_signal_connect (G_OBJECT (menu), "show",
+	g_signal_connect (G_OBJECT (menuitem), "show",
 			  G_CALLBACK (panel_context_menu_setup_delete_panel_item),
-			  menuitem);
+			  panel_widget->toplevel);
 
 	add_menu_separator (menu);
 
@@ -204,12 +175,5 @@ panel_context_menu_create (PanelWidget *panel)
 
 	panel_context_menu_build_edition (panel, retval);
 
-	//FIXME: can we get rid of this? (needed by menu_get_panel())
-	g_object_set_data (G_OBJECT (retval), "menu_panel", panel);
-
-	g_signal_connect (retval, "event",
-			  G_CALLBACK (panel_context_menu_check_for_screen),
-			  NULL);
-
 	return retval;
 }
