@@ -33,8 +33,6 @@ G_DEFINE_TYPE (PanelMenuBarObject, panel_menu_bar_object, GTK_TYPE_MENU_BAR)
 #define PANEL_MENU_BAR_OBJECT_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), PANEL_TYPE_MENU_BAR_OBJECT, PanelMenuBarObjectPrivate))
 
 struct _PanelMenuBarObjectPrivate {
-	PanelWidget *panel;
-
 	PanelOrientation orientation;
 };
 
@@ -76,6 +74,10 @@ panel_menu_bar_object_icon_get_pixel_size (GtkIconSize size)
       return 32;
     case GTK_ICON_SIZE_LARGE_TOOLBAR:
       return 24;
+    case GTK_ICON_SIZE_SMALL_TOOLBAR:
+    case GTK_ICON_SIZE_BUTTON:
+    case GTK_ICON_SIZE_MENU:
+    case GTK_ICON_SIZE_INVALID:
     default:
       return 16;
   }
@@ -85,29 +87,12 @@ static void
 panel_menu_bar_object_init (PanelMenuBarObject *menubar)
 {
         GtkStyleContext *context;
-        GtkCssProvider *provider;
 
 	menubar->priv = PANEL_MENU_BAR_OBJECT_GET_PRIVATE (menubar);
 
-        provider = gtk_css_provider_new ();
-        gtk_css_provider_load_from_data (provider,
-                                         "PanelMenuBarObject {\n"
-                                         " border-width: 0px;\n"
-                                         "}",
-                                         -1, NULL);
         context = gtk_widget_get_style_context (GTK_WIDGET (menubar));
-        gtk_style_context_add_provider (context,
-                                        GTK_STYLE_PROVIDER (provider),
-                                        GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
-        g_object_unref (provider);
+
 	gtk_style_context_add_class (context, "gnome-panel-menu-bar");
-
-	if (menubar->priv->orientation & PANEL_HORIZONTAL_MASK)
-		gtk_style_context_add_class (context, GTK_STYLE_CLASS_HORIZONTAL);
-	else
-		gtk_style_context_add_class (context, GTK_STYLE_CLASS_VERTICAL);
-
-	menubar->priv->panel = NULL;
 }
 
 static void
@@ -208,8 +193,6 @@ void
 panel_menu_bar_object_object_load_finish (PanelMenuBarObject *menubar,
 					  PanelWidget        *panel)
 {
-	menubar->priv->panel = panel;
-
 	/* we didn't do this on "applet-added" since we didn't have the panel yet */
         panel_menu_bar_object_update_orientation (menubar);
 	panel_menu_bar_object_update_text_gravity (menubar);
@@ -320,8 +303,6 @@ void
 panel_menu_bar_object_set_orientation (PanelMenuBarObject *menubar,
 				       PanelOrientation    orientation)
 {
-	GtkStyleContext *context;
-
         g_return_if_fail (PANEL_IS_MENU_BAR_OBJECT (menubar));
 
         if (menubar->priv->orientation == orientation)
@@ -329,16 +310,6 @@ panel_menu_bar_object_set_orientation (PanelMenuBarObject *menubar,
 
         menubar->priv->orientation = orientation;
 
-	context = gtk_widget_get_style_context (GTK_WIDGET (menubar));
-	if (orientation & PANEL_HORIZONTAL_MASK) {
-		gtk_style_context_add_class (context, GTK_STYLE_CLASS_HORIZONTAL);
-		gtk_style_context_remove_class (context, GTK_STYLE_CLASS_VERTICAL);
-	} else {
-		gtk_style_context_add_class (context, GTK_STYLE_CLASS_VERTICAL);
-		gtk_style_context_remove_class (context, GTK_STYLE_CLASS_HORIZONTAL);
-	}
-	gtk_widget_reset_style (GTK_WIDGET (menubar));
-
         panel_menu_bar_object_update_orientation (menubar);
 
         g_object_notify (G_OBJECT (menubar), "orientation");
