@@ -112,19 +112,25 @@ panel_menu_bar_init (PanelMenuBar *menubar)
 {
 	gchar *applications_menu;
 	GtkIconSize icon_size;
+	GtkWidget *label;
+	GtkStyleContext *context;
 
 	menubar->priv = PANEL_MENU_BAR_GET_PRIVATE (menubar);
 
 	menubar->priv->info = NULL;
 
 	applications_menu = get_applications_menu ();
-	menubar->priv->applications_menu = create_applications_menu (applications_menu, NULL, TRUE);
+	menubar->priv->applications_menu = create_applications_menu (applications_menu, NULL);
 	g_free (applications_menu);
 
 	menubar->priv->applications_item = panel_image_menu_item_new2 ();
 	gtk_menu_item_set_label (GTK_MENU_ITEM (menubar->priv->applications_item),
 				 _("Applications"));
 
+	label = gtk_bin_get_child (GTK_BIN (menubar->priv->applications_item));
+	context = gtk_widget_get_style_context (label);
+	gtk_style_context_add_class (context, "gp-text-color");
+
 	icon_size = panel_menu_bar_object_icon_get_size ();
 	menubar->priv->image = gtk_image_new_from_icon_name (PANEL_ICON_MAIN_MENU, icon_size);
 	gtk_image_set_pixel_size (GTK_IMAGE (menubar->priv->image),
@@ -155,14 +161,6 @@ panel_menu_bar_parent_set (GtkWidget *widget,
 	g_assert (!parent || PANEL_IS_WIDGET (parent));
 
 	menubar->priv->panel = (PanelWidget *) parent;
-
-	if (menubar->priv->applications_menu)
-		panel_applet_menu_set_recurse (GTK_MENU (menubar->priv->applications_menu),
-					       "menu_panel",
-					       menubar->priv->panel);
-	if (menubar->priv->places_item)
-		panel_place_menu_item_set_panel (menubar->priv->places_item,
-						 menubar->priv->panel);
 }
 
 static void
