@@ -36,7 +36,6 @@
 #include "applet.h"
 #include "panel-widget.h"
 #include "panel-util.h"
-#include "panel-globals.h"
 #include "menu.h"
 #include "panel-lockdown.h"
 #include "panel-a11y.h"
@@ -277,20 +276,6 @@ panel_menu_button_set_property (GObject      *object,
 	}
 }
 
-static void
-panel_menu_button_associate_panel (PanelMenuButton *button)
-{
-	PanelWidget *panel_widget = NULL;
-
-	if (!button->priv->menu)
-		return;
-
-	if (button->priv->toplevel)
-		panel_widget = panel_toplevel_get_panel_widget (button->priv->toplevel);
-
-	panel_applet_menu_set_recurse (GTK_MENU (button->priv->menu), "menu_panel", panel_widget);
-}
-
 static void
 panel_menu_button_parent_set (GtkWidget *widget,
 			      GtkWidget *previous_parent)
@@ -306,7 +291,6 @@ panel_menu_button_parent_set (GtkWidget *widget,
 	else
 		button->priv->toplevel = NULL;
 
-	panel_menu_button_associate_panel (button);
 	panel_menu_button_set_icon (button);
 
 	if (GTK_WIDGET_CLASS (panel_menu_button_parent_class)->parent_set)
@@ -340,8 +324,6 @@ panel_menu_button_menu_deactivated (PanelMenuButton *button)
 
 	gtk_widget_unset_state_flags (GTK_WIDGET (button),
 				      GTK_STATE_FLAG_PRELIGHT);
-
-	button_widget_set_ignore_leave (BUTTON_WIDGET (button), FALSE);
 }
 
 static void 
@@ -378,8 +360,7 @@ panel_menu_button_create_menu (PanelMenuButton *button)
 
 		filename = panel_menu_path_root_to_filename (button->priv->path_root);
 		button->priv->menu = create_applications_menu (filename,
-							       button->priv->menu_path,
-							       TRUE);
+							       button->priv->menu_path);
 	} else
 		button->priv->menu = create_main_menu (panel_widget);
 
@@ -387,8 +368,6 @@ panel_menu_button_create_menu (PanelMenuButton *button)
 				   GTK_WIDGET (button),
 				   (GtkMenuDetachFunc) panel_menu_button_menu_detacher);
 
-	panel_menu_button_associate_panel (button);
-
 	g_signal_connect_swapped (button->priv->menu, "deactivate",
 				  G_CALLBACK (panel_menu_button_menu_deactivated),
 				  button);
@@ -409,8 +388,6 @@ panel_menu_button_popup_menu (PanelMenuButton *button,
 
 	panel_toplevel_push_autohide_disabler (button->priv->toplevel);
 
-	button_widget_set_ignore_leave (BUTTON_WIDGET (button), TRUE);
-
 	screen = gtk_window_get_screen (GTK_WINDOW (button->priv->toplevel));
 	gtk_menu_set_screen (GTK_MENU (button->priv->menu), screen);
 
