@@ -1,60 +1,16 @@
 
 
 
-#include <glib-object.h>
 #include "panel-typebuiltins.h"
 
-
 /* enumerations from "../gnome-panel/panel-enums.h" */
 #include "../gnome-panel/panel-enums.h"
-static const GEnumValue _panel_frame_edge_values[] = {
-  { PANEL_EDGE_NONE, "PANEL_EDGE_NONE", "none" },
-  { PANEL_EDGE_TOP, "PANEL_EDGE_TOP", "top" },
-  { PANEL_EDGE_BOTTOM, "PANEL_EDGE_BOTTOM", "bottom" },
-  { PANEL_EDGE_LEFT, "PANEL_EDGE_LEFT", "left" },
-  { PANEL_EDGE_RIGHT, "PANEL_EDGE_RIGHT", "right" },
-  { 0, NULL, NULL }
-};
-
-GType
-panel_frame_edge_get_type (void)
-{
-  static GType type = 0;
-
-  if (!type)
-    type = g_enum_register_static ("PanelFrameEdge", _panel_frame_edge_values);
-
-  return type;
-}
-
-static const GEnumValue _panel_state_values[] = {
-  { PANEL_STATE_NORMAL, "PANEL_STATE_NORMAL", "normal" },
-  { PANEL_STATE_AUTO_HIDDEN, "PANEL_STATE_AUTO_HIDDEN", "auto-hidden" },
-  { PANEL_STATE_HIDDEN_UP, "PANEL_STATE_HIDDEN_UP", "hidden-up" },
-  { PANEL_STATE_HIDDEN_DOWN, "PANEL_STATE_HIDDEN_DOWN", "hidden-down" },
-  { PANEL_STATE_HIDDEN_LEFT, "PANEL_STATE_HIDDEN_LEFT", "hidden-left" },
-  { PANEL_STATE_HIDDEN_RIGHT, "PANEL_STATE_HIDDEN_RIGHT", "hidden-right" },
-  { 0, NULL, NULL }
-};
-
-GType
-panel_state_get_type (void)
-{
-  static GType type = 0;
-
-  if (!type)
-    type = g_enum_register_static ("PanelState", _panel_state_values);
-
-  return type;
-}
-
 static const GEnumValue _panel_object_type_values[] = {
   { PANEL_OBJECT_MENU, "PANEL_OBJECT_MENU", "menu" },
   { PANEL_OBJECT_LAUNCHER, "PANEL_OBJECT_LAUNCHER", "launcher" },
   { PANEL_OBJECT_APPLET, "PANEL_OBJECT_APPLET", "applet" },
   { PANEL_OBJECT_ACTION, "PANEL_OBJECT_ACTION", "action" },
   { PANEL_OBJECT_MENU_BAR, "PANEL_OBJECT_MENU_BAR", "menu-bar" },
-  { PANEL_OBJECT_SEPARATOR, "PANEL_OBJECT_SEPARATOR", "separator" },
   { PANEL_OBJECT_USER_MENU, "PANEL_OBJECT_USER_MENU", "user-menu" },
   { 0, NULL, NULL }
 };
@@ -69,7 +25,6 @@ panel_object_type_get_type (void)
 
   return type;
 }
-
 static const GEnumValue _panel_action_button_type_values[] = {
   { PANEL_ACTION_NONE, "PANEL_ACTION_NONE", "none" },
   { PANEL_ACTION_LOCK, "PANEL_ACTION_LOCK", "lock" },
@@ -77,7 +32,6 @@ static const GEnumValue _panel_action_button_type_values[] = {
   { PANEL_ACTION_RUN, "PANEL_ACTION_RUN", "run" },
   { PANEL_ACTION_SEARCH, "PANEL_ACTION_SEARCH", "search" },
   { PANEL_ACTION_FORCE_QUIT, "PANEL_ACTION_FORCE_QUIT", "force-quit" },
-  { PANEL_ACTION_CONNECT_SERVER, "PANEL_ACTION_CONNECT_SERVER", "connect-server" },
   { PANEL_ACTION_HIBERNATE, "PANEL_ACTION_HIBERNATE", "hibernate" },
   { PANEL_ACTION_SUSPEND, "PANEL_ACTION_SUSPEND", "suspend" },
   { PANEL_ACTION_HYBRID_SLEEP, "PANEL_ACTION_HYBRID_SLEEP", "hybrid-sleep" },
@@ -98,7 +52,6 @@ panel_action_button_type_get_type (void)
   return type;
 }
 
-
 /* enumerations from "../gnome-panel/panel-enums-gsettings.h" */
 #include "../gnome-panel/panel-enums-gsettings.h"
 static const GEnumValue _panel_object_pack_type_values[] = {
@@ -118,7 +71,6 @@ panel_object_pack_type_get_type (void)
 
   return type;
 }
-
 static const GEnumValue _panel_orientation_values[] = {
   { PANEL_ORIENTATION_TOP, "PANEL_ORIENTATION_TOP", "top" },
   { PANEL_ORIENTATION_RIGHT, "PANEL_ORIENTATION_RIGHT", "right" },
@@ -137,7 +89,6 @@ panel_orientation_get_type (void)
 
   return type;
 }
-
 static const GEnumValue _panel_animation_speed_values[] = {
   { PANEL_ANIMATION_SLOW, "PANEL_ANIMATION_SLOW", "slow" },
   { PANEL_ANIMATION_MEDIUM, "PANEL_ANIMATION_MEDIUM", "medium" },
@@ -155,25 +106,6 @@ panel_animation_speed_get_type (void)
 
   return type;
 }
-
-static const GEnumValue _panel_background_type_values[] = {
-  { PANEL_BACK_NONE, "PANEL_BACK_NONE", "none" },
-  { PANEL_BACK_COLOR, "PANEL_BACK_COLOR", "color" },
-  { PANEL_BACK_IMAGE, "PANEL_BACK_IMAGE", "image" },
-  { 0, NULL, NULL }
-};
-
-GType
-panel_background_type_get_type (void)
-{
-  static GType type = 0;
-
-  if (!type)
-    type = g_enum_register_static ("PanelBackgroundType", _panel_background_type_values);
-
-  return type;
-}
-
 static const GEnumValue _panel_background_image_style_values[] = {
   { PANEL_BACKGROUND_IMAGE_STYLE_NONE, "PANEL_BACKGROUND_IMAGE_STYLE_NONE", "none" },
   { PANEL_BACKGROUND_IMAGE_STYLE_STRETCH, "PANEL_BACKGROUND_IMAGE_STYLE_STRETCH", "stretch" },
@@ -191,7 +123,6 @@ panel_background_image_style_get_type (void)
 
   return type;
 }
-
 static const GEnumValue _panel_theme_variant_values[] = {
   { PANEL_THEME_VARIANT_SYSTEM, "PANEL_THEME_VARIANT_SYSTEM", "system" },
   { PANEL_THEME_VARIANT_LIGHT, "PANEL_THEME_VARIANT_LIGHT", "light" },
@@ -210,7 +141,6 @@ panel_theme_variant_get_type (void)
   return type;
 }
 
-
 /* enumerations from "../gnome-panel/panel-types.h" */
 #include "../gnome-panel/panel-types.h"
 static const GEnumValue _panel_speed_values[] = {
@@ -233,4 +163,3 @@ panel_speed_get_type (void)
 
 
 
-
