@@ -4,14 +4,11 @@
 #ifndef __PANEL_TYPEBUILTINS_H__
 #define __PANEL_TYPEBUILTINS_H__ 1
 
+#include <glib-object.h>
+
 G_BEGIN_DECLS
 
-
 /* --- ../gnome-panel/panel-enums.h --- */
-#define PANEL_TYPE_FRAME_EDGE panel_frame_edge_get_type()
-GType panel_frame_edge_get_type (void);
-#define PANEL_TYPE_STATE panel_state_get_type()
-GType panel_state_get_type (void);
 #define PANEL_TYPE_OBJECT_TYPE panel_object_type_get_type()
 GType panel_object_type_get_type (void);
 #define PANEL_TYPE_ACTION_BUTTON_TYPE panel_action_button_type_get_type()
@@ -24,8 +21,6 @@ GType panel_object_pack_type_get_type (void);
 GType panel_orientation_get_type (void);
 #define PANEL_TYPE_ANIMATION_SPEED panel_animation_speed_get_type()
 GType panel_animation_speed_get_type (void);
-#define PANEL_TYPE_BACKGROUND_TYPE panel_background_type_get_type()
-GType panel_background_type_get_type (void);
 #define PANEL_TYPE_BACKGROUND_IMAGE_STYLE panel_background_image_style_get_type()
 GType panel_background_image_style_get_type (void);
 #define PANEL_TYPE_THEME_VARIANT panel_theme_variant_get_type()
