@@ -35,9 +35,7 @@
 #include <libpanel-util/panel-xdg.h>
 
 #include "applet.h"
-#include "xstuff.h"
 #include "panel-bindings.h"
-#include "panel-globals.h"
 #include "launcher.h"
 #include "panel-icon-names.h"
 #include "panel-schemas.h"
